CFB_BASE_URL = 'https://raw.githubusercontent.com/saiemgilani/cfbfastR-data/master/pbp/parquet/play_by_play_{season}.parquet'
CFB_ROSTER_URL = 'https://raw.githubusercontent.com/saiemgilani/cfbfastR-data/master/rosters/roster_{season}.parquet'
CFB_TEAM_LOGO_URL  = 'https://raw.githubusercontent.com/saiemgilani/cfbfastR-data/master/teams/teams_colors_logos.parquet'
CFB_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/cfbfastR-data/master/schedules/parquet/schedules_{season}.parquet'
CFB_TEAM_INFO_URL = 'https://raw.githubusercontent.com/saiemgilani/cfbfastR-data/master/team_info/parquet/team_info_{season}.parquet'

NFL_BASE_URL = 'https://raw.githubusercontent.com/nflverse/nflfastR-data/master/data/play_by_play_{season}.parquet'
NFL_PLAYER_STATS_URL = 'https://raw.githubusercontent.com/nflverse/nflfastR-data/master/data/player_stats.parquet'
NFL_ROSTER_URL = 'https://raw.githubusercontent.com/nflverse/nflfastR-roster/master/data/seasons/roster_{season}.csv'
NFL_TEAM_LOGO_URL  = 'https://raw.githubusercontent.com/nflverse/nflfastR-data/master/teams_colors_logos.csv'
NFL_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/nflfastR-data/master/schedules/sched_{season}.parquet'